require 'httparty'

class Cta
  include HTTParty
  @key = nil
  base_uri 'http://www.ctabustracker.com/bustime/api/v1/'
  
  # The current system time for the CTA API
  def self.get_time(params = {})
    response = Cta.send('/gettime')
    return response[:error] ? response : (Time.parse response[:response]['tm'])
  end
  
  # A list of all bus routes
  def self.get_routes(params = {})
    response = Cta.send('/getroutes', params)
    return response[:error] ? response : response[:response]['route']
  end
  
  # A list of cardinal directions for a given route
  def self.get_directions(params = {})
    response = Cta.send('/getdirections', params)
    return response[:error] ? response : response[:response]['dir']
  end
  
  # A list of stops for a given route
  def self.get_stops(params = {})
    response = Cta.send('/getstops', params)
    return response[:error] ? response : response[:response]['stop']
  end
  
  # A list of predicted times for a stop
  def self.get_predictions(params = {})
    response = Cta.send('/getpredictions', params)
    return response[:error] ? response : response[:response]['prd']
  end
  
  # Next time for a stop
  def self.get_next(params = {})
    response = Cta.get_predictions(params)
    newest = response.kind_of?(Array) ? response.first : response
    (((Time.parse newest['prdtm']) - (Cta.get_time)) / 60).ceil
  end
  
  def self.send(route, params = {})
    return { :success => false, :error => "No API key provided." } if @key.nil?
    
    params.merge!({ :key => @key })
    response = get(route, { :query => params })
    
    return { :success => false, :error => "Could not reach CTA servers." } if response.code != 200
    
    return { :success => false, :error => response['bustime_response']['error']['msg'] } if response['bustime_response']['error']
    
    { :success => true, :response => response['bustime_response'] }
  end
  
  def self.set_key(key)
    @key = key
  end
end